%%
% Accompaning measurement values for the paper
% "Exploiting Ultra-Wideband Channel Impulse Responses for Device-free Localization"
% author: Marco Cimdins
% affiliation: Technische Hochschule Lbeck
%%

%clear all 
%close all

%% Open the measurement files
load('cir_measurements_exploiting_cir.mat')

%%
% Measurement settings of the measurement hardware
measSettings.DW1000

%%
% Description of the measurement setup
measSettings.area

%%
% Description of the fields of the idle measurements
description.cir_idle

%%
% Description of the fields of the reference measurements
description.cir_reference

%%
% The actual measurements are found in cir_idle and cir_reference strutures
% An example that read out and plot the magnitude

% Plot the magnitude of an idle CIR measurement
meas_no = 1;
sample = cir_idle(meas_no).cir;

figure()
plot(abs(sample))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')

%%
% Example for reconstructing and alignment of the CIR measurement with sinc-function

% Plot the magnitude of an idle CIR measurement
meas_no = 1;
int_part_offset = 5; % CIR measurements were recorded that many samples prior to the integer part of the LDE of the DW1000

sample = cir_idle(meas_no);
rx_lvl = cir_idle(meas_no).rx_lvl;
        
% Filter CIRs
[reconstructed_cir, reconstructed_time] = reconstruct_cir(sample.cir);

% Find the position, where the leading edge detection algorithm of the
% DW1000 found the start of the first peak
time_skip = find(reconstructed_time >= (int_part_offset+sample.frac_part*1/64)*1e-9);
cir = reconstructed_cir(time_skip(1):end);
time = reconstructed_time(time_skip(1):end);

figure()
plot(time, abs(cir))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')

%%
% Plot the magnitude of a CIR measurment of with a person standing at
% position_id 8 for sensor pair (1,2)
pos_id = 8;
meas_no = 1;
sample = cir_reference.pair1(pos_id).cir(meas_no).cir;

figure()
plot(abs(sample))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')
